diff --git a/win-linux/langs/ca.ts b/win-linux/langs/ca.ts
index c55a259e8..c1859cebe 100644
--- a/win-linux/langs/ca.ts
+++ b/win-linux/langs/ca.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Contrasenya incorrecta del certificat.<br>Si us plau, introduïu de nou
+ Contrasenya incorrecta del certificat.<br>Si us plau, introduïu de nou
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Si continueu guardant en aquest format, es perdran totes les funcions, excepte el text.<br>Estàs segur que vols continuar?
+ Si continueu guardant en aquest format, es perdran totes les funcions, excepte el text.<br>Estàs segur que vols continuar?Document must be saved to continue.<br>Save the document?
- El document s'ha de desar per a continuar.<br>Desar el document?
+ El document s'ha de desar per a continuar.<br>Desar el document?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- Ja existeix %1.<br>Voleu substituir-lo?
+ Ja existeix %1.<br>Voleu substituir-lo?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 No està disponible. Es pot canviar el nom, moure-lo o suprimir-lo.&Voleu eliminar el fitxer de la llista?
+ %1 No està disponible. Es pot canviar el nom, moure-lo o suprimir-lo.&Voleu eliminar el fitxer de la llista?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- El document s'ha de guardar per continuar.&Guardar el document?
+ El document s'ha de guardar per continuar.&Guardar el document?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Si continueu guardant en aquest format, es perdran totes les funcions, excepte el text.&Estàs segur que vols continuar?
+ Si continueu guardant en aquest format, es perdran totes les funcions, excepte el text.&Estàs segur que vols continuar?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 ha estat modificat.&Voleu desar els canvis?
+ %1 ha estat modificat.&Voleu desar els canvis?
@@ -433,7 +433,7 @@
&OK
- &D'accord
+ &D'accord
@@ -481,7 +481,7 @@
&Cancel
- &Cancel·lar
+ &Cancel·lar
diff --git a/win-linux/langs/cs.ts b/win-linux/langs/cs.ts
index 7ac885986..0cd48766d 100644
--- a/win-linux/langs/cs.ts
+++ b/win-linux/langs/cs.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Chybné heslo certifikátu.<br>Zadejte prosím znovu
+ Chybné heslo certifikátu.<br>Zadejte prosím znovu
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- Než budete pokračovat, musíte dokument uložit.<br>Chcete dokument uložit?
+ Než budete pokračovat, musíte dokument uložit.<br>Chcete dokument uložit?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Pokud budete pokračovat v ukládání v tomto formátu, vše kromě textu bude ztraceno.<br>Opravdu chcete pokračovat?
+ Pokud budete pokračovat v ukládání v tomto formátu, vše kromě textu bude ztraceno.<br>Opravdu chcete pokračovat?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 již existuje.<br>Přejete si ho přepsat?
+ %1 již existuje.<br>Přejete si ho přepsat?
@@ -381,7 +381,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 byl upraven.<br>Chcete uložit tyto změny?
+ %1 byl upraven.<br>Chcete uložit tyto změny?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 není dostupný. Možná byl přejmenován, přesunut nebo smazán.<br>Chcete odstranit soubor ze seznamu?
+ %1 není dostupný. Možná byl přejmenován, přesunut nebo smazán.<br>Chcete odstranit soubor ze seznamu?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Pokud budete pokračovat v ukládání v tomto formátu, vše kromě textu bude ztraceno.<br>Opravdu chcete pokračovat?
+ Pokud budete pokračovat v ukládání v tomto formátu, vše kromě textu bude ztraceno.<br>Opravdu chcete pokračovat?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- Než budete pokračovat, musíte dokument uložit.<br>Chcete dokument uložit?
+ Než budete pokračovat, musíte dokument uložit.<br>Chcete dokument uložit?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Storno
+ &Storno
diff --git a/win-linux/langs/da.ts b/win-linux/langs/da.ts
index 73c6e64b3..e70ea3d13 100644
--- a/win-linux/langs/da.ts
+++ b/win-linux/langs/da.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Forkert Certifikatsadgangskode.<br>Prøv at indtaste igen
+ Forkert Certifikatsadgangskode.<br>Prøv at indtaste igen
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Hvis du fortsætter med at gemme i dette format vil alle funktioner undtagen teksten blive væk.<br>Er du sikker på du vil fortsætte?
+ Hvis du fortsætter med at gemme i dette format vil alle funktioner undtagen teksten blive væk.<br>Er du sikker på du vil fortsætte?Document must be saved to continue.<br>Save the document?
- Dokumentet skal gemmes for at fortsætte.<br>Gem dokumentet?
+ Dokumentet skal gemmes for at fortsætte.<br>Gem dokumentet?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 eksisterer allerede.<br>Vil du erstatte den?
+ %1 eksisterer allerede.<br>Vil du erstatte den?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 er ikke tilgængeligt. Det er måske omdøbt, flyttet eller slettet.<br>Vil du fjerne filen fra listen?
+ %1 er ikke tilgængeligt. Det er måske omdøbt, flyttet eller slettet.<br>Vil du fjerne filen fra listen?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument skal gemmes for at fortsætte.<br>Gem dokumentet?
+ Dokument skal gemmes for at fortsætte.<br>Gem dokumentet?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Hvis du fortsætter med at gemme i dette format vil alle funktioner undtagen teksten blive væk.<br>Er du sikker på du vil fortsætte?
+ Hvis du fortsætter med at gemme i dette format vil alle funktioner undtagen teksten blive væk.<br>Er du sikker på du vil fortsætte?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 er blevet ændret.<br>Vil du gemme ændringerne?
+ %1 er blevet ændret.<br>Vil du gemme ændringerne?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Annuller
+ &Annuller
diff --git a/win-linux/langs/de.ts b/win-linux/langs/de.ts
index 9314417fb..bcd17db72 100644
--- a/win-linux/langs/de.ts
+++ b/win-linux/langs/de.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Falsches Zertifikats-Kennwort.<br>Bitte noch einmal eingeben
+ Falsches Zertifikats-Kennwort.<br>Bitte noch einmal eingeben
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Wenn Sie mit dem Speichern in diesem Format fortsetzen, werden alle Objekte außer Text verloren gehen.<br>Möchten Sie wirklich fortsetzen?
+ Wenn Sie mit dem Speichern in diesem Format fortsetzen, werden alle Objekte außer Text verloren gehen.<br>Möchten Sie wirklich fortsetzen?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 ist bereits vorhanden.<br>Wollen Sie es ersetzen?
+ %1 ist bereits vorhanden.<br>Wollen Sie es ersetzen?
@@ -381,7 +381,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 wurde geändert.<br>Möchten Sie diese Änderungen speichern?
+ %1 wurde geändert.<br>Möchten Sie diese Änderungen speichern?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 ist nicht verfügbar. Es wurde vermutlich umbenannt, gelöscht oder verschoben.<br>Wollen Sie die Datei aus der Liste entfernen?
+ %1 ist nicht verfügbar. Es wurde vermutlich umbenannt, gelöscht oder verschoben.<br>Wollen Sie die Datei aus der Liste entfernen?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Wenn Sie mit dem Speichern in diesem Format fortsetzen, werden alle Objekte außer Text verloren gehen.<br>Möchten Sie wirklich fortsetzen?
+ Wenn Sie mit dem Speichern in diesem Format fortsetzen, werden alle Objekte außer Text verloren gehen.<br>Möchten Sie wirklich fortsetzen?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- Das Dokument muss gespeichert werden, um fortzusetzen.<br>Möchten Sie das Dokument speichern?
+ Das Dokument muss gespeichert werden, um fortzusetzen.<br>Möchten Sie das Dokument speichern?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Abbrechen
+ &Abbrechen
diff --git a/win-linux/langs/es.ts b/win-linux/langs/es.ts
index e85200f3f..53da553c5 100644
--- a/win-linux/langs/es.ts
+++ b/win-linux/langs/es.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Contraseña de certificado incorrecta.<br>Por favor, introduzca de nuevo
+ Contraseña de certificado incorrecta.<br>Por favor, introduzca de nuevo
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- El documento debe guardarse para continuar.<br>¿Guardar el documento?
+ El documento debe guardarse para continuar.<br>¿Guardar el documento?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Si sigue guardando en este formato todas las características a excepción del texto se perderán.<br>¿Está seguro de que quiere continuar?
+ Si sigue guardando en este formato todas las características a excepción del texto se perderán.<br>¿Está seguro de que quiere continuar?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 ya existe.<br>¿Desea reemplazarlo?
+ %1 ya existe.<br>¿Desea reemplazarlo?
@@ -381,7 +381,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 ha sido modificado.<br>¿Quiere guardar los cambios?
+ %1 ha sido modificado.<br>¿Quiere guardar los cambios?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 no está disponible. Es posible que haya sido renombrado, transferido o eliminado.<br>¿Desea eliminar el archivo de la lista?
+ %1 no está disponible. Es posible que haya sido renombrado, transferido o eliminado.<br>¿Desea eliminar el archivo de la lista?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Si sigue guardando en este formato todas las características a excepción del texto se perderán.<br>¿Está seguro de que quiere continuar?
+ Si sigue guardando en este formato todas las características a excepción del texto se perderán.<br>¿Está seguro de que quiere continuar?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- El documento debe guardarse para continuar.<br>¿Guardar el documento?
+ El documento debe guardarse para continuar.<br>¿Guardar el documento?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Cancelar
+ &Cancelar
diff --git a/win-linux/langs/et.ts b/win-linux/langs/et.ts
index 6e5774835..4c25243ec 100644
--- a/win-linux/langs/et.ts
+++ b/win-linux/langs/et.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Vale sertifikaadi salasõna.<br> Palun sisesta uuesti
+ Vale sertifikaadi salasõna.<br> Palun sisesta uuesti
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Kui sa jätkad selles formaadis salvestamist, siis kõik peale teksti kaob ära.<br> Oled kindel, et tahad jätkata?
+ Kui sa jätkad selles formaadis salvestamist, siis kõik peale teksti kaob ära.<br> Oled kindel, et tahad jätkata?Document must be saved to continue.<br>Save the document?
- Dokument tuleb salvestada, et jätkata.<br>Salvestasid dokumendi?
+ Dokument tuleb salvestada, et jätkata.<br>Salvestasid dokumendi?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 juba eksisteerib.<br> Kas sa soovid selle asendada?
+ %1 juba eksisteerib.<br> Kas sa soovid selle asendada?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 ei ole saadaval. Ta võib olla uue nimega, muudetud või kustutatud.<br> Kas sa soovid faili listist eemaldada?
+ %1 ei ole saadaval. Ta võib olla uue nimega, muudetud või kustutatud.<br> Kas sa soovid faili listist eemaldada?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument tuleb salvestada, et jätkata.<br> Salvesta dokument?
+ Dokument tuleb salvestada, et jätkata.<br> Salvesta dokument?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Kui sa jätkad selles formaadis salvestamist, siis kõik peale teksti kaob ära.<br>Oled kindel, et tahad jätkata?
+ Kui sa jätkad selles formaadis salvestamist, siis kõik peale teksti kaob ära.<br>Oled kindel, et tahad jätkata?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 on muudetud.<br>Kas sa tahad muutused salvestada?
+ %1 on muudetud.<br>Kas sa tahad muutused salvestada?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Tühista
+ &Tühista
diff --git a/win-linux/langs/fr.ts b/win-linux/langs/fr.ts
index cc810efa3..be99fda44 100644
--- a/win-linux/langs/fr.ts
+++ b/win-linux/langs/fr.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Mot de passe de certificat incorrect.<br>Veuillez l’entrer à nouveau
+ Mot de passe de certificat incorrect.<br>Veuillez l’entrer à nouveau
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- Le document doit être enregistré pour continuer.<br>Enregistrer le document ?
+ Le document doit être enregistré pour continuer.<br>Enregistrer le document ?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Si vous continuez à enregistrer dans ce format toutes les fonctions sauf le texte seront perdues.<br>Êtes-vous sûr de vouloir continuer ?
+ Si vous continuez à enregistrer dans ce format toutes les fonctions sauf le texte seront perdues.<br>Êtes-vous sûr de vouloir continuer ?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 existe déjà.<br>Voulez-vous le replacer ?
+ %1 existe déjà.<br>Voulez-vous le replacer ?
@@ -381,7 +381,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 a été modifié.<br>Voulez-vous enregistrer les changements ?
+ %1 a été modifié.<br>Voulez-vous enregistrer les changements ?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 n’est pas disponible. Il peut être renomé, supprimé ou déplacé.<br>Voulez-vous supprimer le fichier de la liste ?
+ %1 n’est pas disponible. Il peut être renomé, supprimé ou déplacé.<br>Voulez-vous supprimer le fichier de la liste ?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Si vous continuez à enregistrer dans ce format toutes les fonctions sauf le texte seront perdues.<br>Êtes-vous sûr de vouloir continuer ?
+ Si vous continuez à enregistrer dans ce format toutes les fonctions sauf le texte seront perdues.<br>Êtes-vous sûr de vouloir continuer ?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- Le document doit être enregistré pour continuer.<br>Enregistrer le document ?
+ Le document doit être enregistré pour continuer.<br>Enregistrer le document ?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Annuler
+ &Annuler
diff --git a/win-linux/langs/ga.ts b/win-linux/langs/ga.ts
index b3783fd43..dde645f20 100644
--- a/win-linux/langs/ga.ts
+++ b/win-linux/langs/ga.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Pasfhocal mícheart teastas.<br>Cuir isteach arís é
+ Pasfhocal mícheart teastas.<br>Cuir isteach arís é
@@ -118,17 +118,17 @@
%1 has been changed. Save changes?
- Mionathraíodh %1.<br>Ar mhaith leat na hathruithe a shábháil?
+ Mionathraíodh %1.<br>Ar mhaith leat na hathruithe a shábháil?Some data will lost.<br>Continue?
- Má leanann tú ar aghaidh ag sábháil san fhormáid seo caillfear gach gné seachas an téacs.<br> An bhfuil tú cinnte gur mhaith leat leanúint ar aghaidh?
+ Má leanann tú ar aghaidh ag sábháil san fhormáid seo caillfear gach gné seachas an téacs.<br> An bhfuil tú cinnte gur mhaith leat leanúint ar aghaidh?Document must be saved to continue.<br>Save the document?
- Caithfear an doiciméad a shábháil chun leanúint ar aghaidh.<br>Sábháil an doiciméad?
+ Caithfear an doiciméad a shábháil chun leanúint ar aghaidh.<br>Sábháil an doiciméad?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 ann cheana.<br>Ar mhaith leat ceann eile a chur ina ionad?
+ %1 ann cheana.<br>Ar mhaith leat ceann eile a chur ina ionad?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- Níl %1 ar fáil.D’fhéadfaí é a athainmniú, a bhogadh nó a scriosadh.<br>Ar mhaith leat an comhad a bhaint den liosta?
+ Níl %1 ar fáil.D’fhéadfaí é a athainmniú, a bhogadh nó a scriosadh.<br>Ar mhaith leat an comhad a bhaint den liosta?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Caithfear doiciméad a shábháil chun leanúint ar aghaidh.<br>Sábháil an doiciméad?
+ Caithfear doiciméad a shábháil chun leanúint ar aghaidh.<br>Sábháil an doiciméad?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Má leanann tú ar aghaidh ag sábháil san fhormáid seo caillfear gach gné seachas an téacs.<br>An bhfuil tú cinnte gur mhaith leat leanúint ar aghaidh?
+ Má leanann tú ar aghaidh ag sábháil san fhormáid seo caillfear gach gné seachas an téacs.<br>An bhfuil tú cinnte gur mhaith leat leanúint ar aghaidh?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- Mionathraíodh %1.<br>Ar mhaith leat na hathruithe a shábháil?
+ Mionathraíodh %1.<br>Ar mhaith leat na hathruithe a shábháil?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Cealaigh
+ &Cealaigh
diff --git a/win-linux/langs/hi.ts b/win-linux/langs/hi.ts
index 1fa62274e..ecf2b9dca 100644
--- a/win-linux/langs/hi.ts
+++ b/win-linux/langs/hi.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- गलत सर्टिफिकेट पासवर्ड।<br>कृपया एक बार फिर दर्ज करें
+ गलत सर्टिफिकेट पासवर्ड।<br>कृपया एक बार फिर दर्ज करें
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- यदि आप इसी प्रारूप में सहेजना जारी रखेंगे तो टेक्स्ट के आलावा सभी विशेषताएँ लुप्त हो जाएँगी।<br>क्या आप सुनिश्चित तौर पर जारी रखना चाहते हैं?
+ यदि आप इसी प्रारूप में सहेजना जारी रखेंगे तो टेक्स्ट के आलावा सभी विशेषताएँ लुप्त हो जाएँगी।<br>क्या आप सुनिश्चित तौर पर जारी रखना चाहते हैं?Document must be saved to continue.<br>Save the document?
- जारी रखने के लिए दस्तावेज़ को सहेजना आवश्यक है।<br>दस्तावेज़ को सहेजें?
+ जारी रखने के लिए दस्तावेज़ को सहेजना आवश्यक है।<br>दस्तावेज़ को सहेजें?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 पहले से मौजूद है।<br>क्या आप इसे प्रतिस्थापित करना चाहते हैं?
+ %1 पहले से मौजूद है।<br>क्या आप इसे प्रतिस्थापित करना चाहते हैं?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 यह उपलब्ध नहीं है। शायद इसका नाम बदला गया है, इसे कहीं और डाला गया है या इसे डिलीट कर दिया गया है।<br>क्या आप सूची से यह फ़ाइल को हटाना चाहते हैं?
+ %1 यह उपलब्ध नहीं है। शायद इसका नाम बदला गया है, इसे कहीं और डाला गया है या इसे डिलीट कर दिया गया है।<br>क्या आप सूची से यह फ़ाइल को हटाना चाहते हैं?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- जारी रखने के लिए दस्तावेज़ को सहेजना आवश्यक है।<br>दस्तावेज़ को सहेजें?
+ जारी रखने के लिए दस्तावेज़ को सहेजना आवश्यक है।<br>दस्तावेज़ को सहेजें?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- यदि आप इसी प्रारूप में सहेजना जारी रखेंगे तो टेक्स्ट के आलावा सभी विशेषताएँ लुप्त हो जाएँगी।<br>क्या आप सुनिश्चित तौर पर जारी रखना चाहते हैं?
+ यदि आप इसी प्रारूप में सहेजना जारी रखेंगे तो टेक्स्ट के आलावा सभी विशेषताएँ लुप्त हो जाएँगी।<br>क्या आप सुनिश्चित तौर पर जारी रखना चाहते हैं?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 को संशोधित कर लिया गया है। <br>क्या आप बदलावों को सहेजना चाहते हैं?
+ %1 को संशोधित कर लिया गया है। <br>क्या आप बदलावों को सहेजना चाहते हैं?
@@ -433,7 +433,7 @@
&OK
- &ठीक है
+ &ठीक है
@@ -481,7 +481,7 @@
&Cancel
- &रद्द करें
+ &रद्द करें
diff --git a/win-linux/langs/hr.ts b/win-linux/langs/hr.ts
index ad94dc646..70727923e 100644
--- a/win-linux/langs/hr.ts
+++ b/win-linux/langs/hr.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Pogrešna lozinka potvrde.<br>Molimo unesite je još jednom
+ Pogrešna lozinka potvrde.<br>Molimo unesite je još jednom
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Ako nastavite spremanje u ovom formatu, izgubiti će se sve značajke osim teksta.<br>Jeste li sigurni da želite nastaviti?
+ Ako nastavite spremanje u ovom formatu, izgubiti će se sve značajke osim teksta.<br>Jeste li sigurni da želite nastaviti?Document must be saved to continue.<br>Save the document?
- Dokument se mora spremiti za nastavak.<br>Želite li spremiti dokument?
+ Dokument se mora spremiti za nastavak.<br>Želite li spremiti dokument?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 već postoji.<br>Želite li ga zamijeniti?
+ %1 već postoji.<br>Želite li ga zamijeniti?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 nije dostupna. Možda je preimenovana, premještena ili izbrisana.<br>Želite li ukloniti datoteku s popisa?
+ %1 nije dostupna. Možda je preimenovana, premještena ili izbrisana.<br>Želite li ukloniti datoteku s popisa?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Da biste mogli nastaviti dokument se mora spremiti.<br>Želite li spremiti dokument?
+ Da biste mogli nastaviti dokument se mora spremiti.<br>Želite li spremiti dokument?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Ako nastavite spremanje u ovom formatu, izgubiti će se sve značajke osim teksta.<br>Jeste li sigurni da želite nastaviti?
+ Ako nastavite spremanje u ovom formatu, izgubiti će se sve značajke osim teksta.<br>Jeste li sigurni da želite nastaviti?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 je izmijenjen.<br>Želite li spremiti promjene?
+ %1 je izmijenjen.<br>Želite li spremiti promjene?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Odustani
+ &Odustani
diff --git a/win-linux/langs/hu.ts b/win-linux/langs/hu.ts
index c1d8b32a5..a514469cc 100644
--- a/win-linux/langs/hu.ts
+++ b/win-linux/langs/hu.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Nem megfelelő tanúsítványjelszó.<br>Kérjük, adja meg újra a jelszót
+ Nem megfelelő tanúsítványjelszó.<br>Kérjük, adja meg újra a jelszót
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Amennyiben ebben a formátumban szeretné menteni, a szövegen kívül minden funkciót elveszít.<br>Biztos, hogy folytatja?
+ Amennyiben ebben a formátumban szeretné menteni, a szövegen kívül minden funkciót elveszít.<br>Biztos, hogy folytatja?Document must be saved to continue.<br>Save the document?
- A folytatáshoz mentenie kell a dokumentumot.<br>Menti a dokumentumot?
+ A folytatáshoz mentenie kell a dokumentumot.<br>Menti a dokumentumot?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 már létezik.<br>Lecseréli?
+ %1 már létezik.<br>Lecseréli?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 nem elérhető. Lehet, hogy átnevezésre, áthelyezésre vagy törlésre került.<br>Eltávolítja a fájlt a listáról?
+ %1 nem elérhető. Lehet, hogy átnevezésre, áthelyezésre vagy törlésre került.<br>Eltávolítja a fájlt a listáról?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- A folytatáshoz mentenie kell a dokumentumot.<br>Menti a dokumentumot?
+ A folytatáshoz mentenie kell a dokumentumot.<br>Menti a dokumentumot?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Amennyiben ebben a formátumban szeretné menteni, a szövegen kívül minden funkciót elveszít.<br>Biztos, hogy folytatja?
+ Amennyiben ebben a formátumban szeretné menteni, a szövegen kívül minden funkciót elveszít.<br>Biztos, hogy folytatja?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 módosítva lett.<br>Menti a módosításokat?
+ %1 módosítva lett.<br>Menti a módosításokat?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Mégse
+ &Mégse
diff --git a/win-linux/langs/hy.ts b/win-linux/langs/hy.ts
index 95a158343..988656236 100644
--- a/win-linux/langs/hy.ts
+++ b/win-linux/langs/hy.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Լիցենզիայի ծածկագիրը սխալ է<br>Խնդրում ենք կրկին մուտքագրել։
+ Լիցենզիայի ծածկագիրը սխալ է<br>Խնդրում ենք կրկին մուտքագրել։
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Եթե շարունակեք պահպանել այս ֆորմատով, բոլոր գործառույթները, բացի տեքստից, կկորչեն։<br>Վստա՞հ եք, որ ցանկանում եք շարունակել։
+ Եթե շարունակեք պահպանել այս ֆորմատով, բոլոր գործառույթները, բացի տեքստից, կկորչեն։<br>Վստա՞հ եք, որ ցանկանում եք շարունակել։Document must be saved to continue.<br>Save the document?
- Շարունակելու համար պետք է պահպանել փաստաթուղթը։<br>Պահպանե՞լ փաստաթուղթը։
+ Շարունակելու համար պետք է պահպանել փաստաթուղթը։<br>Պահպանե՞լ փաստաթուղթը։
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 արդեն գոյություն ունի։<br>Ցանկանու՞մ եք փոխարինել այն։
+ %1 արդեն գոյություն ունի։<br>Ցանկանու՞մ եք փոխարինել այն։
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 հասանելի չէ։ Հնարավոր է, որ այն անվանափոխվել է, տեղափոխվել կամ ջնջվել։<br>Ցանկանու՞մ եք ֆայլը հեռացնել ցանկից։
+ %1 հասանելի չէ։ Հնարավոր է, որ այն անվանափոխվել է, տեղափոխվել կամ ջնջվել։<br>Ցանկանու՞մ եք ֆայլը հեռացնել ցանկից։
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Շարունակելու համար փաստաթուղթը պետք է պահպանվի։<br>Պահպանե՞լ փաստաթուղթը։
+ Շարունակելու համար փաստաթուղթը պետք է պահպանվի։<br>Պահպանե՞լ փաստաթուղթը։
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Եթե շարունակեք պահպանել այս ֆորմատով, բոլոր ֆունկցիաները, բացի տեքստից, կկորչեն։<br>Վստա՞հ եք, որ ցանկանում եք շարունակել։
+ Եթե շարունակեք պահպանել այս ֆորմատով, բոլոր ֆունկցիաները, բացի տեքստից, կկորչեն։<br>Վստա՞հ եք, որ ցանկանում եք շարունակել։
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 փոփոխվել է<br>Ցանկանու՞մ եք պահպանել փոփոխությունները։
+ %1 փոփոխվել է<br>Ցանկանու՞մ եք պահպանել փոփոխությունները։
@@ -433,7 +433,7 @@
&OK
- &Լավ
+ &Լավ
@@ -481,7 +481,7 @@
&Cancel
- &Չեղարկել
+ &Չեղարկել
diff --git a/win-linux/langs/in.ts b/win-linux/langs/in.ts
index 853eb3c07..4fe5c5d71 100644
--- a/win-linux/langs/in.ts
+++ b/win-linux/langs/in.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Sertifikat kata sandi salah.<br>Silakan masukkan sekali lagi
+ Sertifikat kata sandi salah.<br>Silakan masukkan sekali lagi
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Jika Anda masih menyimpan dalam format ini semua fitur kecuali teks akan hilang.<br>Yakin ingin melanjutkan?
+ Jika Anda masih menyimpan dalam format ini semua fitur kecuali teks akan hilang.<br>Yakin ingin melanjutkan?Document must be saved to continue.<br>Save the document?
- Dokumen harus disimpan untuk melanjutkan.<br>Simpan dokumen?
+ Dokumen harus disimpan untuk melanjutkan.<br>Simpan dokumen?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 sudah ada.<br>Apakah Anda ingin menggantinya?
+ %1 sudah ada.<br>Apakah Anda ingin menggantinya?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 tidak tersedia. Mungkin telah berganti nama, berpindah atau hilang.<br>Hapus file dari daftar?
+ %1 tidak tersedia. Mungkin telah berganti nama, berpindah atau hilang.<br>Hapus file dari daftar?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokumen harus disimpan untuk melanjutkan.<br>Simpan dokumen?
+ Dokumen harus disimpan untuk melanjutkan.<br>Simpan dokumen?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Jika Anda masih menyimpan dalam format ini semua fitur kecuali teks akan hilang.<br>Yakin ingin melanjutkan?
+ Jika Anda masih menyimpan dalam format ini semua fitur kecuali teks akan hilang.<br>Yakin ingin melanjutkan?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 telah berubah.<br>Simpan perubahan?
+ %1 telah berubah.<br>Simpan perubahan?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Batal
+ &Batal
diff --git a/win-linux/langs/it_IT.ts b/win-linux/langs/it_IT.ts
index 717ac23c1..a5af763a9 100644
--- a/win-linux/langs/it_IT.ts
+++ b/win-linux/langs/it_IT.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Password del certificato errata.<br>Inserire nuovamente
+ Password del certificato errata.<br>Inserire nuovamente
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- Il documento deve essere salvato per continuare.<br>Salvare il documento?
+ Il documento deve essere salvato per continuare.<br>Salvare il documento?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Se continua a salvare in questo formato tutte le caratteristiche tranne il testo saranno perse.<br>Sei sicuro di voler continuare?
+ Se continua a salvare in questo formato tutte le caratteristiche tranne il testo saranno perse.<br>Sei sicuro di voler continuare?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 è già esistente.<br>Vuoi sostituirlo?
+ %1 è già esistente.<br>Vuoi sostituirlo?
@@ -376,7 +376,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 è stato modificato.<br>Desideri salvare le modifiche?
+ %1 è stato modificato.<br>Desideri salvare le modifiche?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 non è disponibile. Il file è stato rinominato, spostato o rimosso.<br>Vuoi Rimuoverlo da questa lista?
+ %1 non è disponibile. Il file è stato rinominato, spostato o rimosso.<br>Vuoi Rimuoverlo da questa lista?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Se continua a salvare in questo formato tutte le caratteristiche tranne il testo saranno perse.<br>Sei sicuro di voler continuare?
+ Se continua a salvare in questo formato tutte le caratteristiche tranne il testo saranno perse.<br>Sei sicuro di voler continuare?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- Il documento deve essere salvato per continuare.<br>Salvare il documento?
+ Il documento deve essere salvato per continuare.<br>Salvare il documento?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Annulla
+ &Annulla
diff --git a/win-linux/langs/ja.ts b/win-linux/langs/ja.ts
index 4b45573a1..25febccb7 100644
--- a/win-linux/langs/ja.ts
+++ b/win-linux/langs/ja.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- 証明書のパスワードが間違っています。<br>もう一度入力してください
+ 証明書のパスワードが間違っています。<br>もう一度入力してください
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- このフォーマットで保存すると、テキストを除く全ての機能が失われます。<br>続けますか?
+ このフォーマットで保存すると、テキストを除く全ての機能が失われます。<br>続けますか?Document must be saved to continue.<br>Save the document?
- 続けるには、ドキュメントを保存する必要があります。<br>ドキュメントを保存しますか?
+ 続けるには、ドキュメントを保存する必要があります。<br>ドキュメントを保存しますか?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 は既存します。<br>置き換えますか?
+ %1 は既存します。<br>置き換えますか?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 は利用できません。名前を変更したか、移動または削除された可能性があります。<br>リストからファイルを削除しますか?
+ %1 は利用できません。名前を変更したか、移動または削除された可能性があります。<br>リストからファイルを削除しますか?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- 続けるには、ドキュメントを保存する必要があります。<br>ドキュメントを保存しますか?
+ 続けるには、ドキュメントを保存する必要があります。<br>ドキュメントを保存しますか?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- このフォーマットで保存すると、テキストを除く全ての機能が失われます。<br>続けますか?
+ このフォーマットで保存すると、テキストを除く全ての機能が失われます。<br>続けますか?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 を変更しました。<br>変更を保存しますか?
+ %1 を変更しました。<br>変更を保存しますか?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &キャンセル
+ &キャンセル
diff --git a/win-linux/langs/lt.ts b/win-linux/langs/lt.ts
index 60de67565..0f75cfd0f 100644
--- a/win-linux/langs/lt.ts
+++ b/win-linux/langs/lt.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Neteisingas pažymėjimo slaptažodis.<br>Bandykite dar kartą
+ Neteisingas pažymėjimo slaptažodis.<br>Bandykite dar kartą
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Jei ir toliau saugosite šiuo formatu, visos funkcijos, išskyrus tekstą, bus prarastos.<br>Ar norite tęsti?
+ Jei ir toliau saugosite šiuo formatu, visos funkcijos, išskyrus tekstą, bus prarastos.<br>Ar norite tęsti?Document must be saved to continue.<br>Save the document?
- Norint tęsti, dokumentas privalo būti išsaugotas.<br>Išsaugoti dokumentą?
+ Norint tęsti, dokumentas privalo būti išsaugotas.<br>Išsaugoti dokumentą?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 jau egzistuoja.<br>Ar norite jį pakeisti?
+ %1 jau egzistuoja.<br>Ar norite jį pakeisti?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 negalimas. Jis galėjo būti pervardytas, perkeltas arba ištrintas.<br>Ar norite panaikinti failą iš sąrašo?
+ %1 negalimas. Jis galėjo būti pervardytas, perkeltas arba ištrintas.<br>Ar norite panaikinti failą iš sąrašo?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Norint tęsti, dokumentas privalo būti išsaugotas.<br>Išsaugoti dokumentą?
+ Norint tęsti, dokumentas privalo būti išsaugotas.<br>Išsaugoti dokumentą?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Jei ir toliau saugosite šiuo formatu, visos funkcijos, išskyrus tekstą, bus prarastos.<br>Ar norite tęsti?
+ Jei ir toliau saugosite šiuo formatu, visos funkcijos, išskyrus tekstą, bus prarastos.<br>Ar norite tęsti?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 buvo pakeistas.<br>Ar norite išsaugoti pakeitimus?
+ %1 buvo pakeistas.<br>Ar norite išsaugoti pakeitimus?
@@ -433,7 +433,7 @@
&OK
- &GERAI
+ &GERAI
@@ -481,7 +481,7 @@
&Cancel
- &Atšaukti
+ &Atšaukti
diff --git a/win-linux/langs/lv.ts b/win-linux/langs/lv.ts
index aa0fbefe4..7b247dcb7 100644
--- a/win-linux/langs/lv.ts
+++ b/win-linux/langs/lv.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Nepareiza sertifikāta parole.<br>Lūdzu, ievadiet vēlreiz
+ Nepareiza sertifikāta parole.<br>Lūdzu, ievadiet vēlreiz
@@ -118,17 +118,17 @@
%1 has been changed. Save changes?
- %1 tika izmainīts.<br>Vai jūs vēlaties saglabāt izmaiņas?
+ %1 tika izmainīts.<br>Vai jūs vēlaties saglabāt izmaiņas?Some data will lost.<br>Continue?
- Ja jūs turpināsiet saglabāt šajā formātā, visas iezīmes zudīs, izņemot tekstu.<br>Vai esat pārliecināts, ka vēlaties turpināt?
+ Ja jūs turpināsiet saglabāt šajā formātā, visas iezīmes zudīs, izņemot tekstu.<br>Vai esat pārliecināts, ka vēlaties turpināt?Document must be saved to continue.<br>Save the document?
- Dokuments jāsaglabā, lai turpinātu.<br>Saglabāt dokumentu?
+ Dokuments jāsaglabā, lai turpinātu.<br>Saglabāt dokumentu?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 jau pastāv.<br>Vai jūs vēlaties to aizstāt?
+ %1 jau pastāv.<br>Vai jūs vēlaties to aizstāt?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 nav pieejams. Tas varētu būt pārdēvēts, pārvietots vai izdzēsts.<br>Vai jūs vēlaties izņemt failu no saraksta?
+ %1 nav pieejams. Tas varētu būt pārdēvēts, pārvietots vai izdzēsts.<br>Vai jūs vēlaties izņemt failu no saraksta?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokuments jāsaglabā, lai turpinātu.<br>Saglabāt dokumentu?
+ Dokuments jāsaglabā, lai turpinātu.<br>Saglabāt dokumentu?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Ja turpināsiet saglabāt šajā formātā, visas iezīmēs zudīs, izņemot tekstu.<br>Vai esat pārliecināts, ka vēlaties turpināt?
+ Ja turpināsiet saglabāt šajā formātā, visas iezīmēs zudīs, izņemot tekstu.<br>Vai esat pārliecināts, ka vēlaties turpināt?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 tika izmainīts.<br>Vai jūs vēlaties saglabāt izmaiņas?
+ %1 tika izmainīts.<br>Vai jūs vēlaties saglabāt izmaiņas?
@@ -433,7 +433,7 @@
&OK
- &Labi
+ &Labi
@@ -481,7 +481,7 @@
&Cancel
- &Atcelt
+ &Atcelt
diff --git a/win-linux/langs/nl.ts b/win-linux/langs/nl.ts
index 9606968ac..c1ceb90c3 100644
--- a/win-linux/langs/nl.ts
+++ b/win-linux/langs/nl.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Verkeerd certificaat wachtwoord.<br>Voer nogmaals in
+ Verkeerd certificaat wachtwoord.<br>Voer nogmaals in
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Als u doorgaat met het opslaan in dit formaat zullen alle functies, behalve de tekst, verloren gaan.<br>Weet u zeker dat u wilt doorgaan?
+ Als u doorgaat met het opslaan in dit formaat zullen alle functies, behalve de tekst, verloren gaan.<br>Weet u zeker dat u wilt doorgaan?Document must be saved to continue.<br>Save the document?
- The Document moet worden opgeslagen om verder te kunnen gaan.<br>Document opslaan?
+ The Document moet worden opgeslagen om verder te kunnen gaan.<br>Document opslaan?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 bestaat al.<br>Wilt u het vervangen?
+ %1 bestaat al.<br>Wilt u het vervangen?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 is niet beschikbaar. Het is misschien hernoemd, verplaatst of verwijderd.<br>Wilt u het bestand van de lijst verwijderen??
+ %1 is niet beschikbaar. Het is misschien hernoemd, verplaatst of verwijderd.<br>Wilt u het bestand van de lijst verwijderen??
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Document moet worden opgeslagen om verder te kunnen gaan.<br>Document opslaan?
+ Document moet worden opgeslagen om verder te kunnen gaan.<br>Document opslaan?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Als u doorgaat met het opslaan in dit formaat zullen alle functies, behalve de tekst, verloren gaan.<br>Weet u zeker dat u wilt doorgaan?
+ Als u doorgaat met het opslaan in dit formaat zullen alle functies, behalve de tekst, verloren gaan.<br>Weet u zeker dat u wilt doorgaan?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 is aangepast.<br>Wilt u de veranderingen opslaan?
+ %1 is aangepast.<br>Wilt u de veranderingen opslaan?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Annuleren
+ &Annuleren
diff --git a/win-linux/langs/no.ts b/win-linux/langs/no.ts
index f64791dc3..0a5a5fa21 100644
--- a/win-linux/langs/no.ts
+++ b/win-linux/langs/no.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Feil passord for sertifikatet.<br>Vennligst skriv inn på nytt
+ Feil passord for sertifikatet.<br>Vennligst skriv inn på nytt
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Hvis du fortsetter å lagre i dette formatet, vil alle funksjoner bortsett fra teksten gå tapt.<br>Er du sikker på at du vil fortsette?
+ Hvis du fortsetter å lagre i dette formatet, vil alle funksjoner bortsett fra teksten gå tapt.<br>Er du sikker på at du vil fortsette?Document must be saved to continue.<br>Save the document?
- Dokumentet må lagres for å kunne fortsette.<br>Lagre dokumentet?
+ Dokumentet må lagres for å kunne fortsette.<br>Lagre dokumentet?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 eksisterer allerede.<br>Vil du erstatte den?
+ %1 eksisterer allerede.<br>Vil du erstatte den?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 er ikke tilgjengelig. Den kan gis nytt navn, flyttes eller slettes.<br>Vil du fjerne filen fra listen?
+ %1 er ikke tilgjengelig. Den kan gis nytt navn, flyttes eller slettes.<br>Vil du fjerne filen fra listen?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokumentet må lagres for å kunne fortsette.<br>Lagre dokumentet?
+ Dokumentet må lagres for å kunne fortsette.<br>Lagre dokumentet?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Hvis du fortsetter å lagre i dette formatet, vil alle funksjoner bortsett fra teksten gå tapt.<br>Er du sikker på at du vil fortsette?
+ Hvis du fortsetter å lagre i dette formatet, vil alle funksjoner bortsett fra teksten gå tapt.<br>Er du sikker på at du vil fortsette?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 har blit endret.<br>Vil du lagre endringene?
+ %1 har blit endret.<br>Vil du lagre endringene?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Avbryt
+ &Avbryt
diff --git a/win-linux/langs/pl.ts b/win-linux/langs/pl.ts
index 21ef3efff..a267e3533 100644
--- a/win-linux/langs/pl.ts
+++ b/win-linux/langs/pl.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Błędne hasło certyfikatu.<br>Prosimy wpisać ponownie
+ Błędne hasło certyfikatu.<br>Prosimy wpisać ponownie
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument musi być zapisany, aby kontynuować.<br>Zapisać dokument?
+ Dokument musi być zapisany, aby kontynuować.<br>Zapisać dokument?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Jeśli będziesz kontynuować zapisywanie w tym formacie, wszystkie funkcje z wyjątkiem tekstu zostaną utracone.<br>Czy na pewno chcesz kontynuować?
+ Jeśli będziesz kontynuować zapisywanie w tym formacie, wszystkie funkcje z wyjątkiem tekstu zostaną utracone.<br>Czy na pewno chcesz kontynuować?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 już istnieje.<br>Czy chcesz go zastąpić?
+ %1 już istnieje.<br>Czy chcesz go zastąpić?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 jest niedostępny. Został przeniesiony, usunięty lub zmieniono jego nazwę.<br>Czy chcesz usunąć plik z listy?
+ %1 jest niedostępny. Został przeniesiony, usunięty lub zmieniono jego nazwę.<br>Czy chcesz usunąć plik z listy?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument musi być zapisany, aby kontynuować.<br>Zapisać dokument?
+ Dokument musi być zapisany, aby kontynuować.<br>Zapisać dokument?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Jeśli będziesz kontynuować zapisywanie w tym formacie, wszystkie funkcje z wyjątkiem tekstu zostaną utracone.<br>Czy na pewno chcesz kontynuować?
+ Jeśli będziesz kontynuować zapisywanie w tym formacie, wszystkie funkcje z wyjątkiem tekstu zostaną utracone.<br>Czy na pewno chcesz kontynuować?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 został zmieniony.<br>Czy chcesz zapisać zmiany?
+ %1 został zmieniony.<br>Czy chcesz zapisać zmiany?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Anuluj
+ &Anuluj
diff --git a/win-linux/langs/pt_BR.ts b/win-linux/langs/pt_BR.ts
index 25331b3a5..31a287afd 100644
--- a/win-linux/langs/pt_BR.ts
+++ b/win-linux/langs/pt_BR.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Senha do certificado errada.<br>Insira mais uma vez
+ Senha do certificado errada.<br>Insira mais uma vez
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- O documento deve estar salvo para continuar.<br>Salvar o documento?
+ O documento deve estar salvo para continuar.<br>Salvar o documento?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Se continuar salvando nesse formato, a formatação será perdida.<br>Quer continuar?
+ Se continuar salvando nesse formato, a formatação será perdida.<br>Quer continuar?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 já existe.<br>Você quer substituí-lo?
+ %1 já existe.<br>Você quer substituí-lo?
@@ -376,7 +376,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 foi modificado.<br>Deseja salvar as alterações?
+ %1 foi modificado.<br>Deseja salvar as alterações?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 não está disponível. Ele foi movido ou excluído.<br>Deseja remover o arquivo da lista?
+ %1 não está disponível. Ele foi movido ou excluído.<br>Deseja remover o arquivo da lista?
@@ -410,7 +410,7 @@
Some data will lost.<br>Continue?
- Se continuar salvando nesse formato, a formatação será perdida.<br>Quer continuar?
+ Se continuar salvando nesse formato, a formatação será perdida.<br>Quer continuar?
@@ -420,7 +420,7 @@
Document must be saved to continue.<br>Save the document?
- O documento deve estar salvo para continuar.<br>Salvar o documento?
+ O documento deve estar salvo para continuar.<br>Salvar o documento?
@@ -441,7 +441,7 @@
&OK
- &OK
+ &OK
@@ -489,7 +489,7 @@
&Cancel
- &Cancelar
+ &Cancelar
diff --git a/win-linux/langs/ro.ts b/win-linux/langs/ro.ts
index 454379868..21d4a311d 100644
--- a/win-linux/langs/ro.ts
+++ b/win-linux/langs/ro.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Parolă de certificat incorectă.<br>Vă rugăm să o introduceți din nou
+ Parolă de certificat incorectă.<br>Vă rugăm să o introduceți din nou
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Dacă veți continua salvarea în acest format, toate caracteristicile în afară de text vor fi pierdute.<br>Sigur doriți să continuați?
+ Dacă veți continua salvarea în acest format, toate caracteristicile în afară de text vor fi pierdute.<br>Sigur doriți să continuați?Document must be saved to continue.<br>Save the document?
- Documentul trebuie salvat pentru a continua.<br>Salvați documentul?
+ Documentul trebuie salvat pentru a continua.<br>Salvați documentul?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 există deja.<br>Înlocuiți?
+ %1 există deja.<br>Înlocuiți?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 nu este disponibil. Poate fi redenumit, mutat sau șters.<br>Doriți să eliminați fișierul din listă?
+ %1 nu este disponibil. Poate fi redenumit, mutat sau șters.<br>Doriți să eliminați fișierul din listă?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Documentul trebuie salvat pentru a continua.<br>Salvați documentul?
+ Documentul trebuie salvat pentru a continua.<br>Salvați documentul?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Dacă veți continua salvarea în acest format, toate caracteristicile în afară de text vor fi pierdute.<br>Sigur doriți să continuați?
+ Dacă veți continua salvarea în acest format, toate caracteristicile în afară de text vor fi pierdute.<br>Sigur doriți să continuați?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 a fost modificat.<br>Doriți să salvați modificările?
+ %1 a fost modificat.<br>Doriți să salvați modificările?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Anulare
+ &Anulare
diff --git a/win-linux/langs/ru.ts b/win-linux/langs/ru.ts
index 5a08aa2a5..04da74c71 100644
--- a/win-linux/langs/ru.ts
+++ b/win-linux/langs/ru.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Неправильный пароль сертификата.<br>Пожалуйста, введите пароль еще раз
+ Неправильный пароль сертификата.<br>Пожалуйста, введите пароль еще раз
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- Необходимо сохранить документ для продолжения.<br>Сохранить?
+ Необходимо сохранить документ для продолжения.<br>Сохранить?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Если Вы продолжите сохранение в этот формат, весь функционал, кроме текста, будет потерян.<br>Вы действительно хотите продолжить?
+ Если Вы продолжите сохранение в этот формат, весь функционал, кроме текста, будет потерян.<br>Вы действительно хотите продолжить?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 уже существует.<br>Хотите его перезаписать?
+ %1 уже существует.<br>Хотите его перезаписать?
@@ -381,7 +381,7 @@
%1 is modified.<br>Do you want to keep changes?
- Файл %1 был изменен.<br>Вы хотите сохранить изменения?
+ Файл %1 был изменен.<br>Вы хотите сохранить изменения?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 недоступен. Возможно, он был переименован, перемещен или удален.<br>Хотите удалить его из списка?
+ %1 недоступен. Возможно, он был переименован, перемещен или удален.<br>Хотите удалить его из списка?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Если Вы продолжите сохранение в этот формат, весь функционал, кроме текста, будет потерян.<br>Вы действительно хотите продолжить?
+ Если Вы продолжите сохранение в этот формат, весь функционал, кроме текста, будет потерян.<br>Вы действительно хотите продолжить?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- Необходимо сохранить документ для продолжения.<br>Сохранить?
+ Необходимо сохранить документ для продолжения.<br>Сохранить?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Отмена
+ &Отмена
diff --git a/win-linux/langs/sk.ts b/win-linux/langs/sk.ts
index 8eb74aaec..84014696e 100644
--- a/win-linux/langs/sk.ts
+++ b/win-linux/langs/sk.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Nesprávne heslo certifikátu.<br>Zadajte znova
+ Nesprávne heslo certifikátu.<br>Zadajte znova
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument musí byť uložený, aby ste mohli pokračovať.<br>Uložiť dokument?
+ Dokument musí byť uložený, aby ste mohli pokračovať.<br>Uložiť dokument?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- Ak budete pokračovať v ukladaní v tomto formáte, všetky funkcie okrem textu sa stratia.<br>Ste si istý, že chcete pokračovať?
+ Ak budete pokračovať v ukladaní v tomto formáte, všetky funkcie okrem textu sa stratia.<br>Ste si istý, že chcete pokračovať?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 už existuje.<br>Chcete ho nahradiť?
+ %1 už existuje.<br>Chcete ho nahradiť?
@@ -381,7 +381,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 bol upravený.<br>Chcete zmeny zachovať?
+ %1 bol upravený.<br>Chcete zmeny zachovať?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 neexistuje.<br>Odstrániť súbor zo zoznamu?
+ %1 neexistuje.<br>Odstrániť súbor zo zoznamu?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- Ak budete pokračovať v ukladaní v tomto formáte, všetky funkcie okrem textu sa stratia.<br>Ste si istý, že chcete pokračovať?
+ Ak budete pokračovať v ukladaní v tomto formáte, všetky funkcie okrem textu sa stratia.<br>Ste si istý, že chcete pokračovať?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument musí byť uložený, aby ste mohli pokračovať.<br>Uložiť dokument?
+ Dokument musí byť uložený, aby ste mohli pokračovať.<br>Uložiť dokument?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Zrušiť
+ &Zrušiť
diff --git a/win-linux/langs/sl.ts b/win-linux/langs/sl.ts
index 41a341a08..12e0e7c09 100644
--- a/win-linux/langs/sl.ts
+++ b/win-linux/langs/sl.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Napačno geslo certifikata.<br>Poskusi znova
+ Napačno geslo certifikata.<br>Poskusi znova
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Če želite nadaljevati s shranjevanjem v tem formatu, bodo izgubljene vse lastnosti, razen teksta.<br>Ste prepričani, da želite nadaljevati?
+ Če želite nadaljevati s shranjevanjem v tem formatu, bodo izgubljene vse lastnosti, razen teksta.<br>Ste prepričani, da želite nadaljevati?Document must be saved to continue.<br>Save the document?
- Dokument mora biti shranjen pred nadaljevanjem.<br>Želiš shraniti dokument?
+ Dokument mora biti shranjen pred nadaljevanjem.<br>Želiš shraniti dokument?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 že obstaja.<br>Jo želite zamenjati?
+ %1 že obstaja.<br>Jo želite zamenjati?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 ni na voljo. Lahko je bil preimenovan, premaknjen ali izbrisan.<br>Ali želite, da ga izbrišemo iz seznama?
+ %1 ni na voljo. Lahko je bil preimenovan, premaknjen ali izbrisan.<br>Ali želite, da ga izbrišemo iz seznama?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokument mora biti pred nadaljevanjem shranjen.<br>Želite shraniti dokument?
+ Dokument mora biti pred nadaljevanjem shranjen.<br>Želite shraniti dokument?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Če želite nadaljevati s shranjevanjem v tem formatu, bodo izgubljene vse lastnosti, razen teksta.<br>Ste prepričani, da želite nadaljevati?
+ Če želite nadaljevati s shranjevanjem v tem formatu, bodo izgubljene vse lastnosti, razen teksta.<br>Ste prepričani, da želite nadaljevati?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 je bil spremenjen.<br>Želite shraniti spremembe?
+ %1 je bil spremenjen.<br>Želite shraniti spremembe?
@@ -433,7 +433,7 @@
&OK
- &V redu
+ &V redu
@@ -481,7 +481,7 @@
&Cancel
- &Prekliči
+ &Prekliči
diff --git a/win-linux/langs/sv.ts b/win-linux/langs/sv.ts
index 5b0f1cdc7..aca9d3af2 100644
--- a/win-linux/langs/sv.ts
+++ b/win-linux/langs/sv.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Felaktigt certifikatlösenord.<br>Var vänlig försök igen
+ Felaktigt certifikatlösenord.<br>Var vänlig försök igen
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Om du fortsätter med att spara i detta format så kommer alla funktioner utom texten att gå förlorade.<br>Är du säker på att du vill fortsätta?
+ Om du fortsätter med att spara i detta format så kommer alla funktioner utom texten att gå förlorade.<br>Är du säker på att du vill fortsätta?Document must be saved to continue.<br>Save the document?
- Dokumentet måste sparas för att fortsätta.<br>Spara dokument?
+ Dokumentet måste sparas för att fortsätta.<br>Spara dokument?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 finns redan.<br>Vill du ersätta den?
+ %1 finns redan.<br>Vill du ersätta den?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 är inte tillgänlig. Det är möjligt att filen har bytt namn, flyttats eller tagits bort.<br>Vill du ta bort filen från listan?
+ %1 är inte tillgänlig. Det är möjligt att filen har bytt namn, flyttats eller tagits bort.<br>Vill du ta bort filen från listan?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokumentet måste sparas för att fortsätta.<br>Spara dokumentet?
+ Dokumentet måste sparas för att fortsätta.<br>Spara dokumentet?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Om du fortsätter med att spara i detta format så kommer alla funktioner utom texten att gå förlorade.<br>Är du säker på att du vill fortsätta?
+ Om du fortsätter med att spara i detta format så kommer alla funktioner utom texten att gå förlorade.<br>Är du säker på att du vill fortsätta?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 har ändrats.<br>Vill du spara ändringarna?
+ %1 har ändrats.<br>Vill du spara ändringarna?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Avbryt
+ &Avbryt
diff --git a/win-linux/langs/tr.ts b/win-linux/langs/tr.ts
index 5ed0eb9d7..d342ece57 100644
--- a/win-linux/langs/tr.ts
+++ b/win-linux/langs/tr.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Yanlış sertifika şifresi.<br>Lütfen yeniden deneyin
+ Yanlış sertifika şifresi.<br>Lütfen yeniden deneyin
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Bu formatta kaydetmeye devam ederseniz, metin haricindeki tüm özellikler kaybedilecektir.<br>;Devam etmek istediğinize emin misiniz?
+ Bu formatta kaydetmeye devam ederseniz, metin haricindeki tüm özellikler kaybedilecektir.<br>;Devam etmek istediğinize emin misiniz?Document must be saved to continue.<br>Save the document?
- Devam edebilmek için belgenin kaydedilmesi gerekli.<br>Belgeyi kaydet?
+ Devam edebilmek için belgenin kaydedilmesi gerekli.<br>Belgeyi kaydet?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 zaten var.<br>Üzerine yazmak istiyor musunuz?
+ %1 zaten var.<br>Üzerine yazmak istiyor musunuz?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 mevcut değil. Yeniden isimlendirilmiş, taşınmış veya silimiş olabilir.<br>Dosyayı listeden kaldırmak istediğinize emin misiniz?
+ %1 mevcut değil. Yeniden isimlendirilmiş, taşınmış veya silimiş olabilir.<br>Dosyayı listeden kaldırmak istediğinize emin misiniz?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Devam etmek için belge kaydedilmelidir.<br>Belgeyi kaydet?
+ Devam etmek için belge kaydedilmelidir.<br>Belgeyi kaydet?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Bu formatta kaydetmeye devam ederseniz, metin haricindeki tüm özellikler kaybedilecektir.<br>Devam etmek istediğinize emin misiniz?
+ Bu formatta kaydetmeye devam ederseniz, metin haricindeki tüm özellikler kaybedilecektir.<br>Devam etmek istediğinize emin misiniz?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 değiştirildi.<br>Değişiklikleri kaydetmek istiyor musunuz?
+ %1 değiştirildi.<br>Değişiklikleri kaydetmek istiyor musunuz?
@@ -433,7 +433,7 @@
&OK
- &Tamam
+ &Tamam
@@ -481,7 +481,7 @@
&Cancel
- &İptal
+ &İptal
diff --git a/win-linux/langs/uk.ts b/win-linux/langs/uk.ts
index 623cf5205..f24e19156 100644
--- a/win-linux/langs/uk.ts
+++ b/win-linux/langs/uk.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Неправильний пароль сертифіката.<br>Введіть пароль ще раз
+ Неправильний пароль сертифіката.<br>Введіть пароль ще раз
@@ -123,12 +123,12 @@
Some data will lost.<br>Continue?
- Якщо продовжити зберігання в цьому форматі, усі функції, крім тексту, буде втрачено.<br>Продовжити?
+ Якщо продовжити зберігання в цьому форматі, усі функції, крім тексту, буде втрачено.<br>Продовжити?Document must be saved to continue.<br>Save the document?
- Щоб продовжити, потрібно зберегти документ.<br>Зберегти документ?
+ Щоб продовжити, потрібно зберегти документ.<br>Зберегти документ?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 вже існує.<br>Замінити?
+ %1 вже існує.<br>Замінити?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- Файл %1 недоступний. Він може бути перейменований, переміщений або видалений.<br>Видалити цей файл зі списку?
+ Файл %1 недоступний. Він може бути перейменований, переміщений або видалений.<br>Видалити цей файл зі списку?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Щоб продовжити, потрібно зберегти документ.<br>Зберегти документ?
+ Щоб продовжити, потрібно зберегти документ.<br>Зберегти документ?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Якщо продовжити зберігання в цьому форматі, усі функції, крім тексту, буде втрачено.<br>Продовжити?
+ Якщо продовжити зберігання в цьому форматі, усі функції, крім тексту, буде втрачено.<br>Продовжити?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 змінено.<br>Зберегти зміни?
+ %1 змінено.<br>Зберегти зміни?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Відмінити
+ &Відмінити
diff --git a/win-linux/langs/vi.ts b/win-linux/langs/vi.ts
index 2404755fc..0c2cfa545 100644
--- a/win-linux/langs/vi.ts
+++ b/win-linux/langs/vi.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Mật khẩu chứng nhận bị sai.<br>Vui lòng nhập lại
+ Mật khẩu chứng nhận bị sai.<br>Vui lòng nhập lại
@@ -118,17 +118,17 @@
%1 has been changed. Save changes?
- %1 đã được chỉnh sửa.<br>Bạn có muốn lưu thay đổi không?
+ %1 đã được chỉnh sửa.<br>Bạn có muốn lưu thay đổi không?Some data will lost.<br>Continue?
- Nếu bạn tiếp tục lưu theo định dạng này, tất cả các tính năng ngoại trừ văn bản sẽ bị mất đi.<br>Bạn có chắc muốn tiếp tục không?
+ Nếu bạn tiếp tục lưu theo định dạng này, tất cả các tính năng ngoại trừ văn bản sẽ bị mất đi.<br>Bạn có chắc muốn tiếp tục không?Document must be saved to continue.<br>Save the document?
- Phải lưu tài liệu để tiếp tục.<br>Lưu tài liệu?
+ Phải lưu tài liệu để tiếp tục.<br>Lưu tài liệu?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 đã tồn tại.<br>Bạn có muốn thay thế nó?
+ %1 đã tồn tại.<br>Bạn có muốn thay thế nó?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- Không có %1. Có thể nó đã được đổi tên, chuyển đi hay xóa.<br>Bạn có muốn xóa tập tin này khỏi danh sách không?
+ Không có %1. Có thể nó đã được đổi tên, chuyển đi hay xóa.<br>Bạn có muốn xóa tập tin này khỏi danh sách không?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Phải lưu tài liệu để tiếp tục.<br>Lưu tài liệu?
+ Phải lưu tài liệu để tiếp tục.<br>Lưu tài liệu?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Nếu bạn tiếp tục lưu theo định dạng này, tất cả các tính năng ngoại trừ văn bản sẽ bị mất đi.<br>Bạn có chắc muốn tiếp tục không?
+ Nếu bạn tiếp tục lưu theo định dạng này, tất cả các tính năng ngoại trừ văn bản sẽ bị mất đi.<br>Bạn có chắc muốn tiếp tục không?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 đã được chỉnh sửa.<br>Bạn có muốn lưu thay đổi không??
+ %1 đã được chỉnh sửa.<br>Bạn có muốn lưu thay đổi không??
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Hủy
+ &Hủy
diff --git a/win-linux/langs/zh_CN.ts b/win-linux/langs/zh_CN.ts
index ac42bc5fc..08f191c7b 100644
--- a/win-linux/langs/zh_CN.ts
+++ b/win-linux/langs/zh_CN.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- 证书密码错误。<br>请重新输入
+ 证书密码错误。<br>请重新输入
@@ -118,7 +118,7 @@
Document must be saved to continue.<br>Save the document?
- 文档必须先保存才能继续。<br>是否保存文档?
+ 文档必须先保存才能继续。<br>是否保存文档?
@@ -138,7 +138,7 @@
Some data will lost.<br>Continue?
- 如果您继续以此格式保存,除文本之外的所有功能将丢失。<br>您确定要继续吗?
+ 如果您继续以此格式保存,除文本之外的所有功能将丢失。<br>您确定要继续吗?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1%1已存在。<br>您要替换它吗?
+ %1%1已存在。<br>您要替换它吗?
@@ -376,7 +376,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1已被修改。<br>您要保存更改吗?
+ %1已被修改。<br>您要保存更改吗?
@@ -392,7 +392,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1不可用。它可能被重命名、移动或删除。<br>您要从列表中删除该文件吗?
+ %1不可用。它可能被重命名、移动或删除。<br>您要从列表中删除该文件吗?
@@ -402,7 +402,7 @@
Some data will lost.<br>Continue?
- 如果您继续以此格式保存,除文本之外的所有功能将丢失。<br>您确定要继续吗?
+ 如果您继续以此格式保存,除文本之外的所有功能将丢失。<br>您确定要继续吗?
@@ -412,7 +412,7 @@
Document must be saved to continue.<br>Save the document?
- 文档必须先保存才能继续。<br>是否保存文档?
+ 文档必须先保存才能继续。<br>是否保存文档?
@@ -433,7 +433,7 @@
&OK
- &确定
+ &确定
@@ -481,7 +481,7 @@
&Cancel
- &取消
+ &取消
diff --git a/win-linux/langs/zh_HK.ts b/win-linux/langs/zh_HK.ts
index ff5554ecc..0accf5a83 100644
--- a/win-linux/langs/zh_HK.ts
+++ b/win-linux/langs/zh_HK.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- 憑證密碼錯誤<br>請再輸入一次
+ 憑證密碼錯誤<br>請再輸入一次
@@ -118,17 +118,17 @@
%1 has been changed. Save changes?
- %1 已經被修改。<br>您要儲存變更嗎?
+ %1 已經被修改。<br>您要儲存變更嗎?Some data will lost.<br>Continue?
- 如您繼續以此格式儲存,除了文字以外的所有功能都將會遺失。<br>您確定要繼續嗎?
+ 如您繼續以此格式儲存,除了文字以外的所有功能都將會遺失。<br>您確定要繼續嗎?Document must be saved to continue.<br>Save the document?
- 必須先儲存文件才能繼續。<br>儲存文件?
+ 必須先儲存文件才能繼續。<br>儲存文件?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 已經存在。<br>您要取代它嗎?
+ %1 已經存在。<br>您要取代它嗎?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 無法使用。它可能已被重新命名、移動或刪除。<br>您要從清單中移除檔案嗎?
+ %1 無法使用。它可能已被重新命名、移動或刪除。<br>您要從清單中移除檔案嗎?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- 必須先儲存文件才能繼續。<br>儲存文件?
+ 必須先儲存文件才能繼續。<br>儲存文件?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- 如您繼續以此格式儲存,除了文字以外的所有功能都將會遺失。<br>您確定要繼續嗎?
+ 如您繼續以此格式儲存,除了文字以外的所有功能都將會遺失。<br>您確定要繼續嗎?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 已經被修改。<br>您要儲存變更嗎?
+ %1 已經被修改。<br>您要儲存變更嗎?
@@ -433,7 +433,7 @@
&OK
- &好
+ &好
@@ -481,7 +481,7 @@
&Cancel
- &取消
+ &取消
diff --git a/win-linux/langs/fi.ts b/win-linux/langs/fi.ts
index 6e8f12d91..1df4d17d9 100644
--- a/win-linux/langs/fi.ts
+++ b/win-linux/langs/fi.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Väärä sertifikaatin salasana.<br>Syötä uudelleen
+ Väärä sertifikaatin salasana.<br>Syötä uudelleen
@@ -118,17 +118,17 @@
%1 has been changed. Save changes?
- %1 on muokattu.<br>Haluatko tallentaa muutokset?
+ %1 on muokattu.<br>Haluatko tallentaa muutokset?Some data will lost.<br>Continue?
- Jos jatkat tallennusta tässä muodossa, kaikki muut ominaisuudet paitsi teksti menetetään. <br>Oletko varma, että haluat jatkaa?
+ Jos jatkat tallennusta tässä muodossa, kaikki muut ominaisuudet paitsi teksti menetetään. <br>Oletko varma, että haluat jatkaa?Document must be saved to continue.<br>Save the document?
- Dokumentti on tallennettava ennen jatkamista.<br>Tallennetaanko dokumentti?
+ Dokumentti on tallennettava ennen jatkamista.<br>Tallennetaanko dokumentti?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 on jo olemassa.<br>Haluatko korvata sen?
+ %1 on jo olemassa.<br>Haluatko korvata sen?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 ei ole saatavilla. Se voi olla nimetty uudelleen, siirretty tai poistettu.<br>Haluatko poistaa tiedoston listalta?
+ %1 ei ole saatavilla. Se voi olla nimetty uudelleen, siirretty tai poistettu.<br>Haluatko poistaa tiedoston listalta?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Dokumentti tulee tallentaa ennen jatkamista. <br>Tallennetaanko dokumentti?
+ Dokumentti tulee tallentaa ennen jatkamista. <br>Tallennetaanko dokumentti?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Jos jatkat tallennusta tässä muodossa, kaikki muut ominaisuudet paitsi teksti menetetään.<br> Oletko varma, että haluat jatkaa?
+ Jos jatkat tallennusta tässä muodossa, kaikki muut ominaisuudet paitsi teksti menetetään.<br> Oletko varma, että haluat jatkaa?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 on muokattu.<br>Haluatko tallentaa muutokset?
+ %1 on muokattu.<br>Haluatko tallentaa muutokset?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Peruuta
+ &Peruuta
diff --git a/win-linux/langs/pt_PT.ts b/win-linux/langs/pt_PT.ts
index 82dbd1b2f..e509cfc7a 100644
--- a/win-linux/langs/pt_PT.ts
+++ b/win-linux/langs/pt_PT.ts
@@ -87,7 +87,7 @@
Wrong certificate password.<br>Please enter again
- Password do certificado errada.<br>Por favor insira de novo
+ Password do certificado errada.<br>Por favor insira de novo
@@ -118,17 +118,17 @@
%1 has been changed. Save changes?
- %1 foi modificado.<br>Quer guardar as alterações?
+ %1 foi modificado.<br>Quer guardar as alterações?Some data will lost.<br>Continue?
- Se deseja continuar a guardar neste formato todas as funcionalidades excepto o texto serão perdidas.<br>Tem a certeza que quer continuar?
+ Se deseja continuar a guardar neste formato todas as funcionalidades excepto o texto serão perdidas.<br>Tem a certeza que quer continuar?Document must be saved to continue.<br>Save the document?
- Tem de guardar o documento para continuar.<br>Guardar o documento?
+ Tem de guardar o documento para continuar.<br>Guardar o documento?
@@ -286,7 +286,7 @@
%1 already exists.<br>Do you want to replace it?
- %1 já existe.<br>Quer substituí-lo?
+ %1 já existe.<br>Quer substituí-lo?
@@ -387,7 +387,7 @@
%1 doesn't exists!<br>Remove file from the list?
- %1 não está disponível. Ele pode ter sido renomeado, movido de lugar ou apagado.<br>Deseja remover o ficheiro da lista?
+ %1 não está disponível. Ele pode ter sido renomeado, movido de lugar ou apagado.<br>Deseja remover o ficheiro da lista?
@@ -397,7 +397,7 @@
Document must be saved to continue.<br>Save the document?
- Se continuar a guardar neste formato todas as funcionalidades serão perdidas exceto o texto.<br>Tem a certeza que quer continuar?
+ Se continuar a guardar neste formato todas as funcionalidades serão perdidas exceto o texto.<br>Tem a certeza que quer continuar?
@@ -407,7 +407,7 @@
Some data will lost.<br>Continue?
- Se continuar a guardar neste formato todas as funcionalidades serão perdidas exceto o texto.<br>Tem a certeza que quer continuar?
+ Se continuar a guardar neste formato todas as funcionalidades serão perdidas exceto o texto.<br>Tem a certeza que quer continuar?
@@ -417,7 +417,7 @@
%1 is modified.<br>Do you want to keep changes?
- %1 foi modificado.<br>Quer guardar as alterações?
+ %1 foi modificado.<br>Quer guardar as alterações?
@@ -433,7 +433,7 @@
&OK
- &OK
+ &OK
@@ -481,7 +481,7 @@
&Cancel
- &Cancelar
+ &Cancelar